package com.example.haiwei_mom;

import android.content.Intent;
import android.os.Bundle;

import androidx.databinding.DataBindingUtil;

import com.example.haiwei_mom.adapter.HomeMenuAdapter;
import com.example.haiwei_mom.adapter.ItemClickCall;
import com.example.haiwei_mom.base.BaseActivity;
import com.example.haiwei_mom.base.MyRecultCall;
import com.example.haiwei_mom.base.MyResult;
import com.example.haiwei_mom.data.MenuBeen;
import com.example.haiwei_mom.data.PdaRouters;
import com.example.haiwei_mom.databinding.ActivityHomePageBinding;
import com.example.haiwei_mom.device.BxActivity;
import com.example.haiwei_mom.device.DeviceCheckActivity;
import com.example.haiwei_mom.device.DeviceRepairListActivity;
import com.example.haiwei_mom.device.LubricationActivity;
import com.example.haiwei_mom.device.MaintainActivity;
import com.example.haiwei_mom.ipc.FeedingMaterialsActivity;
import com.example.haiwei_mom.qm.CheckActivity;
import com.example.haiwei_mom.uitls.SharedPreferencesUtils;
import com.example.haiwei_mom.wms.product.BindVehicleActivity;
import com.example.haiwei_mom.wms.product.ProductInActivity;
import com.example.haiwei_mom.wms.product.ProductOutActivity;
import com.example.haiwei_mom.wms.raw.RawInActivity;
import com.example.haiwei_mom.wms.raw.RawOutActivity;
import com.example.haiwei_mom.wms.raw.RawReturnActivity;
import com.example.haiwei_mom.wms.raw.StoreCheckActivity;
import com.example.haiwei_mom.wms.semi.BindingActivity;
import com.example.haiwei_mom.wms.semi.SeimMoveActivity;
import com.example.haiwei_mom.wms.semi.SemiInActivity;
import com.example.haiwei_mom.wms.semi.SemiOutActivity;
import com.google.gson.reflect.TypeToken;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.model.Response;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class HomePageActivity extends BaseActivity implements ItemClickCall {
    private List<MenuBeen> menuList;
    private HomeMenuAdapter adapter;
    private Map<String, Class> map;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        ActivityHomePageBinding binding = DataBindingUtil.setContentView(this, R.layout.activity_home_page);
        adapter = new HomeMenuAdapter(this, this);
        binding.setAdapter(adapter);
        initRequest();
        initMenuMap();


    }

    private void initMenuMap() {
        map = new HashMap<>();
        map.put("半成品入库", SemiInActivity.class);
        map.put("半成品出库", SemiOutActivity.class);
        map.put("半成品调拨", SeimMoveActivity.class);
        map.put("半成品盘点", StoreCheckActivity.class);
        map.put("半成品退库", RawReturnActivity.class);
        map.put("绑定", BindingActivity.class);
        map.put("入库工装绑定", BindVehicleActivity.class);
        map.put("成品批量入库", ProductInActivity.class);
        map.put("成品出库", ProductOutActivity.class);
        map.put("原材料入库", RawInActivity.class);
        map.put("原材料出库", RawOutActivity.class);
        map.put("原材料盘点", StoreCheckActivity.class);
        map.put("原材料退库", RawReturnActivity.class);
        map.put("制品质检", CheckActivity.class);
        map.put("制品复检", CheckActivity.class);
        map.put("机台投料", FeedingMaterialsActivity.class);
        map.put("工装验证", FeedingMaterialsActivity.class);
        map.put("载具绑定", FeedingMaterialsActivity.class);
        map.put("硫化换模", FeedingMaterialsActivity.class);
        map.put("系统配置", ConfigActivity.class);
        map.put("班组管理", ClassItemActivity.class);
        map.put("故障报修", BxActivity.class);
        map.put("故障维修", DeviceRepairListActivity.class);
        map.put("设备巡检", DeviceCheckActivity.class);
        map.put("设备保养", MaintainActivity.class);
        map.put("设备润滑", LubricationActivity.class);
    }

    private void initRequest() {
        menuList = new ArrayList<>();
        OkGo.<MyResult>get(url + "/system/menu/getPdaRouters").tag(this)
                .execute(new MyRecultCall(dialog, this) {
                    @Override
                    public void onSuccess(Response<MyResult> response) {
                        super.onSuccess(response);
                        var body = response.body();
                        if (body.getCode() == 200) {
                            List<PdaRouters> list = gson.fromJson(body.getDataJson(), new TypeToken<List<PdaRouters>>() {
                            }.getType());
                            list.forEach(t -> {
                                MenuBeen menuBeen = new MenuBeen();
                                menuBeen.setMenuName(t.getMenuName());
                                menuBeen.setType(true);
                                menuList.add(menuBeen);
                                var children = t.getChildren();
                                if (children != null) {
                                    children.forEach(t1 -> {
                                        MenuBeen menuBeen1 = new MenuBeen();
                                        menuBeen1.setMenuName(t1.getMenuName());
                                        menuBeen1.setType(false);
                                        menuList.add(menuBeen1);
                                    });
                                }
                            });
                            adapter.setDataList(menuList);
                            adapter.notifyDataSetChanged();
                        } else {
                            myToastUitls.show(body.getMsg());
                        }
                    }
                });
    }


    @Override
    public void onClick(int position) {
        String menuName = menuList.get(position).getMenuName();
        var cls = map.get(menuName);
        if (cls == null) return;
        var intent = new Intent(this, cls);
        intent.putExtra("title",menuName);
        if (menuName.equals("机台投料")){
            intent.putExtra("from","1");
        }else if (menuName.equals("工装验证")){
            intent.putExtra("from","2");
        }else if (menuName.equals("载具绑定")){
            intent.putExtra("from","4");
        }else if (menuName.equals("硫化换模")){
            intent.putExtra("from","5");
        }else if (menuName.equals("半成品退库")){
            intent.putExtra("from","2");
        }

        startActivity(intent);
    }
}