package com.example.haiwei_mom.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.databinding.DataBindingUtil;
import androidx.recyclerview.widget.RecyclerView;

import com.example.haiwei_mom.R;
import com.example.haiwei_mom.databinding.ItemMenuBinding;
import com.example.haiwei_mom.databinding.ItemMenuPBinding;
import com.example.haiwei_mom.data.MenuBeen;

import java.util.List;

/**
 * @author wanghao
 * @date 2024/2/18  16:06
 */
public class HomeMenuAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {
    private List<MenuBeen> dataList;
    private LayoutInflater inflater;
    private Context context;
    private ItemClickCall clickCall;

    public HomeMenuAdapter(Context context,ItemClickCall clickCall) {
        this.context = context;
        inflater=LayoutInflater.from(context);
        this.clickCall=clickCall;
    }

    public void setDataList(List<MenuBeen> dataList) {
        this.dataList = dataList;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

        if (viewType == 1) {
            ItemMenuPBinding binding = DataBindingUtil.inflate(inflater, R.layout.item_menu_p, parent, false);
            return new ViewHolder1(binding);
        } else {
            ItemMenuBinding binding = DataBindingUtil.inflate(inflater, R.layout.item_menu, parent, false);
            return new ViewHolder2(binding);
        }
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder holder, int position) {
        var data = dataList.get(position);
        var menuName = data.getMenuName();
        if (holder instanceof ViewHolder1) {
            ViewHolder1 viewHolder1 = (ViewHolder1) holder;
            viewHolder1.binding.setName(menuName);
            viewHolder1.binding.executePendingBindings();
        } else if (holder instanceof ViewHolder2) {
            ViewHolder2 viewHolder2 = (ViewHolder2) holder;
            viewHolder2.binding.itemMenu.setOnClickListener(v -> {
                clickCall.onClick(position);
            });
            viewHolder2.binding.setName(menuName);
            viewHolder2.binding.executePendingBindings();
        }
    }

    @Override
    public int getItemCount() {
        return dataList==null?0:dataList.size();
    }

    @Override
    public int getItemViewType(int position) {
        var data = dataList.get(position);
        return data.isType()? 1 :2 ;

    }

    public static class ViewHolder1 extends RecyclerView.ViewHolder {
        private ItemMenuPBinding binding;

        public ViewHolder1(ItemMenuPBinding binding) {
            super(binding.getRoot());
            this.binding = binding;
        }
    }

    public static class ViewHolder2 extends RecyclerView.ViewHolder {
        private ItemMenuBinding binding;

        public ViewHolder2(ItemMenuBinding binding) {
            super(binding.getRoot());
            this.binding = binding;
        }
    }
}
